This directory contains scripts to run external CalDAV/CardDAV/WebDAV
testsuites against the Xandikos web server.

Currently supported:

- `Vdirsyncer <https://github.com/pimutils/vdirsyncer>`_
- `litmus <https://www.webdav.org/neon/litmus/>`_
- `caldavtester <https://www.calendarserver.org/CalDAVTester.html>`_
